@@ -37,18 +37,18 @@ def __check_alias__(
 ):
 	present = "--create-alias" in sys.argv and __get_argument__("--create-alias") == alias
 	base = f"/usr/local/bin"
-	if not os.path.exists(base):
+	if not os.path.exists(str(base)):
 		base = f"/usr/bin/"
 	path = f"{base}/{alias}"
 	overwrite = "--overwrite" in sys.argv
-	if (("--force" in sys.argv or "--forced" in sys.argv or overwrite) and present) or (present or not os.path.exists(path)):
+	if (("--force" in sys.argv or "--forced" in sys.argv or overwrite) and present) or (present or not os.path.exists(str(path))):
 		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
-		sudo = Formats.Boolean("--sudo" in sys.argv).convert(true="sudo ",false="")
+		sudo = Boolean("--sudo" in sys.argv).convert(true="sudo ",false="")
 		os.system(f"{sudo}touch {path}")
 		os.system(f"{sudo}chmod +x {path}")
 		os.system(f"{sudo}chown {USER}:{GROUP} {path}")
 		try:
-			Files.File(path=f"{path}", data=file).save()
+			File(path=f"{path}", data=file).save()
 		except:
 			print(f"Unable to create alias $ {alias}.")
 			return None
@@ -63,7 +63,7 @@ def __check_alias__(
 from fil3s import *
 ALIAS = "syst3m"
 SOURCE_NAME = "syst3m"
-SOURCE_PATH = Formats.FilePath(__file__).base(back=3)
+SOURCE_PATH = gfp.base(path=__file__, back=3)
 OS = __get_operating_system__()
 
 # imports.
@@ -81,9 +81,9 @@ try:
 except ImportError as e:
 	import os
 	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {Formats.FilePath(__file__).base(back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
+		os.system(f"/usr/bin/pip3 install -r {FilePath(__file__).base(back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
 	else:
-		os.system(f"pip3 install -r {Formats.FilePath(__file__).base(back=3)}/requirements/requirements.pip")
+		os.system(f"pip3 install -r {FilePath(__file__).base(back=3)}/requirements/requirements.pip")
 
 	# pip imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
@@ -93,6 +93,9 @@ except ImportError as e:
 	from fil3s import *
 	from r3sponse import r3sponse
 
+# imports.
+from r3sponse import ResponseObject
+
 # version.
 try: version = Files.load(f"{SOURCE_PATH}/.version")
 except: version = "unkown"
