@@ -14,9 +14,9 @@ class Env(object):
 		for i in range(string.count("$")):
 			c += 1
 			if string[0] == "$" and c == 1:
-				variable_id, _ = Formats.String(string.split("$")[1]).before_after_first_occurence(slicer=["/","+",">","<","?",";",":","|","\\","]","[","{","}","=","+","(",")","!","@","#","$","%","^","&","*","±","~","`","'",'"'," "], include_after=True)
+				variable_id, _ = String(string.split("$")[1]).before_after_first_occurence(slicer=["/","+",">","<","?",";",":","|","\\","]","[","{","}","=","+","(",")","!","@","#","$","%","^","&","*","±","~","`","'",'"'," "], include_after=True)
 			else:
-				variable_id, _ = Formats.String(string.split("$")[c]).before_after_first_occurence(slicer=["/","+",">","<","?",";",":","|","\\","]","[","{","}","=","+","(",")","!","@","#","$","%","^","&","*","±","~","`","'",'"'," "], include_after=True)
+				variable_id, _ = String(string.split("$")[c]).before_after_first_occurence(slicer=["/","+",">","<","?",";",":","|","\\","]","[","{","}","=","+","(",")","!","@","#","$","%","^","&","*","±","~","`","'",'"'," "], include_after=True)
 			for i in ["/","+",">","<","?",";",":","|","\\","]","[","{","}","=","+","(",")","!","@","#","$","%","^","&","*","±","~","`","'",'"'," "]:
 				variable_id = variable_id.replace(i, "")
 			variable = os.environ.get(variable_id)
@@ -117,9 +117,9 @@ class Env(object):
 	def set_integer(self, id, value):
 		os.environ[id] = str(value)
 	def set_array(self, id, value):
-		os.environ[id] = Formats.Array(value).string(joiner=",")
+		os.environ[id] = Array(value).string(joiner=",")
 	def set_tuple(self, id, value):
-		os.environ[id] = Formats.Array(value).string(joiner=",")
+		os.environ[id] = Array(value).string(joiner=",")
 	def set_dictionary(self, id, value, subkey=""):
 		for key, value in value.items():
 			if subkey == "": lkey = key
